@@ -1,6 +1,6 @@
 package Dancer::Plugin::FlashNote;
 {
-  $Dancer::Plugin::FlashNote::VERSION = '1.0.3';
+  $Dancer::Plugin::FlashNote::VERSION = '1.0.3_1';
 }
 
 # ABSTRACT: support notifications in your Dancer web application
@@ -46,9 +46,9 @@ if ($queue eq 'single') {
 elsif ($queue eq 'multiple') {
    register flash => sub {
       my $value = _get_parameters(@_);
-      my $flash = session($session_hash_key);
-      session($session_hash_key, $flash = []) unless $flash;
+      my $flash = session($session_hash_key) || [];
       push @$flash, $value;
+      session($session_hash_key, $flash);
       return $value;
    };
 } ## end elsif ($queue eq 'multiple')
@@ -56,9 +56,9 @@ elsif ($queue eq 'key_single') {
    register flash => sub {
       my $key   = shift;
       my $value = _get_parameters(@_);
-      my $flash = session($session_hash_key);
-      session($session_hash_key, $flash = {}) unless $flash;
+      my $flash = session($session_hash_key) || {};
       $flash->{$key} = $value;
+      session($session_hash_key, $flash);
       return $value;
    };
 } ## end elsif ($queue eq 'key_single')
@@ -66,9 +66,9 @@ elsif ($queue eq 'key_multiple') {
    register flash => sub {
       my $key   = shift;
       my $value = _get_parameters(@_);
-      my $flash = session($session_hash_key);
-      session($session_hash_key, $flash = {}) unless $flash;
+      my $flash = session($session_hash_key) || {};
       push @{$flash->{$key}}, $value;
+      session($session_hash_key, $flash);
       return $value;
    };
 } ## end elsif ($queue eq 'key_multiple')
@@ -153,7 +153,7 @@ Dancer::Plugin::FlashNote - support notifications in your Dancer web application
 
 =head1 VERSION
 
-version 1.0.3
+version 1.0.3_1
 
 =head1 SYNOPSIS
 
